% fig4.m
% 
% Reads in the ice thickness grids from the best 10% of the runs, plots 
% the mean and ninety for each grid box, and overlays the coastline and ice 
% margin from Ralf's gridded input data sets.  

% Mise en place.  
clear all
close all

% Go get the yes-no vector from data table 2.  
table2 = dlmread('data_table_2.csv', ','); 
yn = table2(2: 101, 16); 

% Get Ralf's gridded ice thicknesses and shore outline for the modern ice sheet.  
H_rg = dlmread('../greve_2011/grl_sr_dev1.2_10_H.dat', '', 6, 0); 
zl_rg = dlmread('../greve_2011/grl_sr_dev1.2_10_zl.dat', '', 6, 0); 
zs_rg = zl_rg.+ H_rg; 

% Initialize the storage matrix H.  
H = zeros(281, 151, nansum(yn)); 

j = 1; 
for i = 1: 1: 100; 
	if yn(i) == 1; 
		dir = sprintf('../6deg_100yr/output/grl10_6deg_100yr_lhs%d/', i); 
		file = sprintf('grl10_6deg_100yr_lhs%d0001.nc', i); 
		command = ['ncdump -p 5 -l 2810 -v H ' dir file ' > foo.txt']; 
		system(command); 
		H_temp = dlmread('foo.txt', ', ', 265, 0); 
		system('rm -f foo.txt'); 
		H_temp(:, 2: 2: 562) = []; 
		H_temp = H_temp'; 
		H(:, :, j) = H_temp; 
		j = j+ 1; 
	end
end

mean_H = mean(H, 3); 
ninety_H = quantile(H, 0.95, 3).- quantile(H, 0.05, 3); 
diff_H = mean_H- flipud(H_rg); 

mask = 9999* ones(281, 151); 
mask(sum(H, 3) > 0) = 1; 
mean_H(mask == 9999) = NaN; 
ninety_H(mask == 9999) = NaN; 
diff_H(sum(H, 3) <= 10^- 3 & flipud(H_rg) <= 10^ -3) = NaN; 

subplot(1, 3, 1)
colormap(flipud(winter(128)))
imagesc(flipud(mean_H)/ 1000)
hold on
% contour(H_rg, [10^ -3 10^ -3], 'linewidth', 1, 'linecolor', [0 0 0])
contour(zs_rg, [10^ -3 10^ -3], 'linewidth', 1, 'linecolor', [0.6 0.6 0.6])
contour(H_rg, [10^ -3 10^ -3], 'linewidth', 1, 'linecolor', [0 0 0])
title('mean of 26 best runs')
set(gca, 'xtick', [1: 50: 151]); 
set(gca, 'ytick', [1: 70: 281]); 
set(gca, 'xticklabel', {'0', '', '' '1500'}); 
set(gca, 'yticklabel', {'0', '', '', '', '2800'}); 
axis([1 151 1 281])
axis equal
colorbar

subplot(1, 3, 2)
colormap(flipud(winter(128)))
imagesc(flipud(ninety_H)/ 1000)
hold on
contour(zs_rg, [10^ -3 10^ -3], 'linewidth', 1, 'linecolor', [0.6 0.6 0.6])
contour(H_rg, [10^ -3 10^ -3], 'linewidth', 1, 'linecolor', [0 0 0])
title('ninety of 26 best runs')
set(gca, 'xtick', [1: 50: 151]); 
set(gca, 'ytick', [1: 70: 281]); 
set(gca, 'xticklabel', {'0', '', '' '1500'}); 
set(gca, 'yticklabel', {'0', '', '', '', '2800'}); 
axis([1 151 1 281])
axis equal
colorbar

figure
subplot(1, 3, 3)
colormap(flipud(jet(128)))
imagesc(flipud(diff_H)/ 1000)
hold on
% contour(H_rg, [10^ -3 10^ -3], 'linewidth', 1, 'linecolor', [0 0 0])
contour(zs_rg, [10^ -3 10^ -3], 'linewidth', 1, 'linecolor', [0.6 0.6 0.6])
contour(flipud(diff_H)/ 1000, [-0.25 0.25], 'linewidth', 1, 'linecolor', [1 1 1])
contour(H_rg, [10^ -3 10^ -3], 'linewidth', 1, 'linecolor', [0 0 0])
title('mean-Actual')
set(gca, 'xtick', [1: 50: 151]); 
set(gca, 'ytick', [1: 70: 281]); 
set(gca, 'xticklabel', {'0', '', '' '1500'}); 
set(gca, 'yticklabel', {'0', '', '', '', '2800'}); 
axis([1 151 1 281])
axis equal
colorbar
