% figs1_5_6.m
% 
% Generates 3 figures.  One shows the different input parameter combinations 
% used in our ensemble; another shows the relationship between different 
% parameter choices and simulated modern ice volume; and the third shows the 
% relationship between different parameters and the simulated change in ice 
% volume between 2005 and 2100.  

% Mise en place.  
clear all
close all

% Set some values.  
obs_vol = 7.1914; 
		% m sle; observed ice volume (Bamber et al., 2001, as gridded by Ralf)
ranges = [1, 5; 	% d'less; range of flow factor
		0, 20; 	% m/ yr/ Pa; basal sliding factor
		30, 70; 	% mW/ sq. m; geothermal heat flux
		1, 5; 	% mm/ day/ deg. C; snow PDD factor
		5, 20]; 	% mm/ day/ deg. C; ice PDD factor
middle = [3, 11.2, 50, 3, 8]; 
		% central values of the input parameters (same order as for ranges)

% Load in the data.  Note that the input parameter values live in columns 2-6, 
% and the simulated ice volumes in 2005 are in column 11.  The good-no good 
% vector is in column 16.  Row #1 is Ralf's run, so we don't want to include it.  
% Sensitivity is the difference between LGM and Eemian ice volumes (columns 8 
% and 7, respectively).  
data = dlmread('data_table_2.csv', ','); 
inputs = data(2: 101, 2: 6); 
ice_vol = data(2: 101, 11); 
sensitivity = data(2: 101, 12)- data(2: 101, 11); 
yn = data(2: 101, 16); 

% Adjust the simulated ice volumes relative to the "correct" answer.  
ice_vol = ice_vol- obs_vol; 

% Plot the relationships between the input parameters.  
figure
for i = 1: 1: 4; 
	for j = 2: 1: 5; 
		if j > i
			subplot(4, 4, 4* (i- 1)+ (j- 1))
			plot([middle(j) middle(j)], [ranges(i, 1) ranges(i, 2)], 'k'); 
			hold on
			plot([ranges(j, 1) ranges(j, 2)], [middle(i) middle(i)], 'k'); 
			input1 = inputs(:, j); 
			input2 = inputs(:, i); 
			plot(input1, input2, '+', 'color', [0.6 0.6 0.6])
			hold on
			input1yn = input1.* yn; 
			input2yn = input2.* yn; 
			plot(input1yn, input2yn, 'b+')
			axis square
			axis([ranges(j, :) ranges(i, :)])
			x_ticks = linspace(ranges(j, 1), ranges(j, 2), 5); 
			y_ticks = linspace(ranges(i, 1), ranges(i, 2), 5); 
% 			x_ticks = sortrows([linspace(ranges(j, 1), ranges(j, 2), 5), middle(j)]); 
% 			y_ticks = sortrows([linspace(ranges(i, 1), ranges(i, 2), 5), middle(i)]); 
			set(gca, 'xtick', x_ticks); 
			set(gca, 'ytick', y_ticks); 
		end
	end
end

% Plot the relationship between the input parameters and 2005 AD ice volumes.  
figure
for i = 1: 1: 5; 
	subplot(2, 3, i)
	plot([middle(i) middle(i)], [-obs_vol 4], 'k'); 
	hold on
	plot(inputs(:, i), ice_vol, '+', 'color', [0.6 0.6 0.6])
	input_yn = inputs(:, i).* yn; 
	ice_vol_yn = ice_vol.* yn; 
	plot(input_yn, ice_vol_yn, 'b+')
	axis([ranges(i, :) -obs_vol 4])
	x_ticks = sortrows([linspace(ranges(i, 1), ranges(i, 2), 5), middle(i)]);
	set(gca, 'xtick', x_ticks); 
% 	set(gca, 'xtick', [ranges(i, 1) middle(i) ranges(i, 2)]); 
	axis square
end

subplot(2, 3, 1)
xlabel('Flow factor')
ylabel('2005 AD ice volume difference, simulated-observed (m sle)')
axis square

subplot(2, 3, 2)
xlabel('Basal sliding factor (m/yr/Pa)')
ylabel(' ')
axis square

subplot(2, 3, 3)
xlabel('Geo. heat flux (mW/m  )')
ylabel(' ')
axis square

subplot(2, 3, 4)
xlabel('Snow PDD factor (mm/day/  C)')
ylabel(' ')
axis square

subplot(2, 3, 5)
xlabel('Ice PDD factor (mm/day/  C)')
ylabel(' ')
axis square


% Plot the relationship between the input parameters and paleo-sensitivity.  
figure
for i = 1: 1: 5; 
	subplot(2, 3, i)
	plot([middle(i) middle(i)], [-0.25 0], 'k'); 
	hold on
	plot(inputs(:, i), sensitivity, '+', 'color', [0.6 0.6 0.6])
	input_yn = inputs(:, i).* yn; 
	sensitivity_yn = sensitivity.* yn; 
	plot(input_yn, sensitivity_yn, 'b+')
	axis([ranges(i, :) -0.25 0])
	x_ticks = sortrows([linspace(ranges(i, 1), ranges(i, 2), 5), middle(i)]);
	set(gca, 'xtick', x_ticks); 
% 	set(gca, 'xtick', [ranges(i, 1) middle(i) ranges(i, 2)]); 
	axis square
end

subplot(2, 3, 1)
xlabel('Flow factor')
ylabel('Ice volume change, 2005-2100 (m sle)')
axis square

subplot(2, 3, 2)
xlabel('Basal sliding factor (m/yr/Pa)')
ylabel(' ')
axis square

subplot(2, 3, 3)
xlabel('Geo. heat flux (mW/m  )')
ylabel(' ')
axis square

subplot(2, 3, 4)
xlabel('Snow PDD factor (mm/day/  C)')
ylabel(' ')
axis square

subplot(2, 3, 5)
xlabel('Ice PDD factor (mm/day/  C)')
ylabel(' ')
axis square
